==> syslinux-3.74-pre18.zip: com32/lib/syslinux/keyboard.c <==
/* ----------------------------------------------------------------------- *
 *
 *   Copyright 2009 Intel Corporation; author: H. Peter Anvin
 *
 *   Permission is hereby granted, free of charge, to any person
 *   obtaining a copy of this software and associated documentation
 *   files (the "Software"), to deal in the Software without
 *   restriction, including without limitation the rights to use,
 *   copy, modify, merge, publish, distribute, sublicense, and/or
 *   sell copies of the Software, and to permit persons to whom
 *   the Software is furnished to do so, subject to the following
 *   conditions:
 *
 *   The above copyright notice and this permission notice shall
 *   be included in all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 *   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 *   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 *   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *   OTHER DEALINGS IN THE SOFTWARE.
 *
 * ----------------------------------------------------------------------- */

#include <syslinux/keyboard.h>
#include <com32.h>

struct syslinux_keyboard_map __syslinux_keyboard_map;

void __constructor __syslinux_get_keyboard_map(void)
{
  static com32sys_t reg;

  reg.eax.w[0] = 0x001e;
  __intcall(0x22, &reg, &reg);
  if (!(reg.eflags.l & EFLAGS_CF)) {
    __syslinux_keyboard_map.version = reg.eax.w[0];
    __syslinux_keyboard_map.length  = reg.edx.w[0];
    __syslinux_keyboard_map.map = MK_PTR(reg.es, reg.ebx.w[0]);
  }
}

==> syslinux-4.00-pre26.zip: com32/lib/syslinux/keyboard.c <==
/* ----------------------------------------------------------------------- *
 *
 *   Copyright 2009 Intel Corporation; author: H. Peter Anvin
 *
 *   Permission is hereby granted, free of charge, to any person
 *   obtaining a copy of this software and associated documentation
 *   files (the "Software"), to deal in the Software without
 *   restriction, including without limitation the rights to use,
 *   copy, modify, merge, publish, distribute, sublicense, and/or
 *   sell copies of the Software, and to permit persons to whom
 *   the Software is furnished to do so, subject to the following
 *   conditions:
 *
 *   The above copyright notice and this permission notice shall
 *   be included in all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 *   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 *   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 *   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *   OTHER DEALINGS IN THE SOFTWARE.
 *
 * ----------------------------------------------------------------------- */

#include <syslinux/keyboard.h>
#include <com32.h>

struct syslinux_keyboard_map __syslinux_keyboard_map;

void __constructor __syslinux_get_keyboard_map(void)
{
    static com32sys_t reg;

    reg.eax.w[0] = 0x001e;
    __intcall(0x22, &reg, &reg);
    if (!(reg.eflags.l & EFLAGS_CF)) {
	__syslinux_keyboard_map.version = reg.eax.w[0];
	__syslinux_keyboard_map.length = reg.ecx.w[0];
	__syslinux_keyboard_map.map = MK_PTR(reg.es, reg.ebx.w[0]);
    }
}
